CMOR functions
==============

.. automodule:: esmvalcore.cmor

Checking compliance
-------------------

.. automodule:: esmvalcore.cmor.check

Automatically fixing issues
---------------------------

.. automodule:: esmvalcore.cmor.fix

Functions for fixing issues
---------------------------

.. automodule:: esmvalcore.cmor.fixes

Using CMOR tables
-----------------

.. automodule:: esmvalcore.cmor.table
